@@ -162,7 +162,7 @@ sub unjson {
 sub jsonrpc_response {
     my ($id, $data) = @_;
 
-    if (exists $data->{error}) {
+    if (ref($data) eq 'HASH' && exists $data->{error}) {
         return jsonrpc_error_response($id => $data->{error});
     }
     return {
@@ -187,7 +187,7 @@ sub build_dispatcher_from_pod {
 
     return dispatch_table_from_pod(
         packages => $pkgs,
-        label    => 'xmlrpc',
+        label    => 'jsonrpc',
     );
 }
 
